@@ -153,6 +153,8 @@ after 'setup_finalize' => sub {
     
     return $self->$orig(@_);
   });
+  
+  $class->_initialize_linked_user_model;
 };
 
 
@@ -191,6 +193,40 @@ sub delete_expired_sessions {
   ])->delete;
 }
 
+sub _initialize_linked_user_model {
+  my $c = shift;
+  
+  my $model = $c->config->{'Plugin::RapidApp::AuthCore'}{linked_user_model} or return undef;
+  my $M = $c->model($model) or die "AuthCore: Failed to load linked_user_model '$model'";
+  
+  my $lSource = $M->result_source;
+  my $lClass  = $lSource->result_class;
+  
+  my $cSource = $c->model('RapidApp::CoreSchema::User')->result_source;
+  my $cClass  = $cSource->result_class;
+  
+  my $key_col = 'username';
+  
+  die "linked_user_model '$model' does not have '$key_col' column" 
+    unless ($lSource->has_column($key_col));
+
+  my @shared_cols = grep { 
+    $_ ne 'id' && $cClass->has_column($_) 
+  } $lClass->columns;
+  
+  $lClass->load_components('+RapidApp::DBIC::Component::LinkedResult');
+  $lSource->{_linked_source} = $cSource;
+  $lSource->{_linked_key_column} = $key_col;
+  $lSource->{_linked_shared_columns} = [@shared_cols];
+  
+  $cClass->load_components('+RapidApp::DBIC::Component::LinkedResult');
+  $cSource->{_linked_source} = $lSource;
+  $cSource->{_linked_key_column} = $key_col;
+  $cSource->{_linked_shared_columns} = [@shared_cols];
+  
+}
+
+
 1;
 
 __END__
