@@ -264,34 +264,46 @@ sub add_db_column($@) {
 			$editable = 0;
 			$creatable = 0;
 		}
-		# Hard-code exclude virtual columns from quick search. May add this support in
-		# the future, but it will require a bit of effort (see the complex/custom code
-		# in multifilters with the conversion into a 'HAVING' clause
-		$opt{no_quick_search} = \1;
 	}
 	# --
   
+  ## -- (see also below comment and commit 2dccadc6f3 which was a regression)
+  ## Hate having to do this, but we have to consider the column profiles here,
+  ## because this happens before they are applied (->add_columns, at the end of this
+  ## method). Specifically, we need to consider profiles which turn OFF allow_add
+  ## and allow_edit, otherwise, we'll clobber those settings if we want to turn
+  ## them on here. And we do need to turn them on, specifically again for the case of
+  ## creatable but not editable, because the default of editable changes the default
+  ## for creatable.
+  $creatable = 0 if List::Util::first {
+    $RapidApp::TableSpec::Column::Profile::NO_ALLOW_ADD_PROFILES{$_}
+  } @{$opt{profiles}||[]};
+  
+  $editable = 0 if List::Util::first {
+    $RapidApp::TableSpec::Column::Profile::NO_ALLOW_EDIT_PROFILES{$_}
+  } @{$opt{profiles}||[]};
+  ## --
+  
+  
 	$opt{allow_edit} = \0 unless ($editable);
 	$opt{allow_add} = \0 unless ($creatable);
   
-  # UPDATE: no longer flip these flags on since this logic should now be reduntant
-  # to the allow_add/edit normalization in RapidApp::Module::DatStor::Column and
-  # this was also conflicting with column profiles which attempt to set these flags
-  #### New: flip the allow edit/add flags on if they are not already set to something,
-  #### and no_column is not set. This is needed for the case of creatable but not
-  #### editable, since the default allow_add is based on the value of allow_edit, which
-  #### is intended for the case of it being set by the user
-  ###unless(jstrue($opt{no_column})) {
-  ###  $opt{allow_edit} //= \1 if ($editable);
-  ###  $opt{allow_add}  //= \1 if ($creatable);
-  ###}
+  #### We do need this code after all -- see above comment. Was removed in 2dccadc6f3
+  # New: flip the allow edit/add flags on if they are not already set to something,
+  # and no_column is not set. This is needed for the case of creatable but not
+  # editable, since the default allow_add is based on the value of allow_edit, which
+  # is intended for the case of it being set by the user
+  unless(jstrue($opt{no_column})) {
+    $opt{allow_edit} //= \1 if ($editable);
+    $opt{allow_add}  //= \1 if ($creatable);
+  }
 
 	unless ($editable or $creatable) {
 		$opt{rel_combo_field_cnf} = $opt{editor} if($opt{editor});
 		$opt{editor} = '' ;
 	}
-	
-	return $self->add_columns(\%opt);
+
+	$self->add_columns(\%opt);
 }
 
 
@@ -990,8 +1002,7 @@ sub add_related_TableSpec {
 	$relspec_prefix .= '.' if ($relspec_prefix and $relspec_prefix ne '');
 	$relspec_prefix .= $rel;
 	
-	my $table = $relclass->table;
-	$table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+	my $table = RapidApp::DBIC::Component::TableSpec::_table_name_safe($relclass->table);
 	my %params = (
 		name => $table,
 		ResultClass => $relclass,
@@ -1567,8 +1578,7 @@ sub get_relationship_column_cnf {
 	my $conf = \%opt;
 	my $info = $conf->{relationship_info} or die "relationship_info is required";
 	
-  my $table = $self->ResultClass->table;
-	$table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+  my $table = RapidApp::DBIC::Component::TableSpec::_table_name_safe($self->ResultClass->table);
 	my $err_info = "rel col: " . $table . ".$rel - " . Dumper($conf);
 	
 	die "displayField is required ($err_info)" unless (defined $conf->{displayField});
@@ -1749,8 +1759,7 @@ sub get_relationship_column_cnf {
     
     $params->{type_filter} = 1 if ($aet eq 'combo');
   
-    my $table = $self->ResultClass->table;
-    $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+    my $table = RapidApp::DBIC::Component::TableSpec::_table_name_safe($self->ResultClass->table);
     my $module_name = 'combo_' . $table . '_' . $colname;
     my $Module = $self->get_or_create_rapidapp_module( $module_name,
       class	  => 'RapidApp::Module::DbicCombo',
@@ -1782,8 +1791,7 @@ sub get_relationship_column_cnf {
     };
     $conf->{auto_editor_params}->{onBUILD} = $onBUILD;
     
-    my $table = $self->ResultClass->table;
-    $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+    my $table = RapidApp::DBIC::Component::TableSpec::_table_name_safe($self->ResultClass->table);
     my $grid_module_name = 'grid_' . $table . '_' . $colname;
     my $GridModule = $self->get_or_create_rapidapp_module( $grid_module_name,
       class	=> 'RapidApp::Module::DbicGrid',
@@ -1929,6 +1937,40 @@ sub get_multi_relationship_column_cnf {
     #  This code path should never happen with RapidDbic, but will still happen for
     #  manual setups where there is no 'open_url', other missing TableSpec data,
     #  or the fallback 'allow_rel_rest_origin => 0' has been set
+    
+    ## -----
+    ## This code block generates the 'resultset_attr' json in perl instead of
+    ## in ExtJS (Ext.encode) so we can reach in and prevent the character sequence ']}'
+    ## which occurs if the last *value* of a hash (Object) happens to be an array
+    ## which only sometimes occurs (and, not consistently across restarts). The bug
+    ## this created was in the compile of Ext.XTemplate, because they use {[ ... ]} as
+    ## markers for inline javascript, so this would cause Syntax Exception.
+    ## The exact JavaScript logic was attempted to be reproduced, just to try to keep
+    ## the behavior as close to the way it was. Note that this codepath itself is
+    ## legacy and only happens in special cases (and then the bug was a special case
+    ## of a special case). This is probably the most ugly code in the whole codebase.
+    my $join_name = $conf->{open_url_multi_rs_join_name};
+    my $personality = $join_name; 
+    my $attr_json = do {
+      my $attr = clone($rel_data->{attrs});   
+      $attr->{join} ||= [];
+      push @{$attr->{join}}, $join_name;
+      @{$attr->{join}} = grep { $_ ne 'me' } @{$attr->{join}};
+      
+      $personality = $attr->{join}[0] if $attr->{join}[0] && $join_name eq 'me';
+      
+      if(scalar(@{$attr->{join}}) == 0)   { delete $attr->{join}; }
+      elsif(scalar(@{$attr->{join}}) == 1) { $attr->{join} = $attr->{join}[0]; }
+      
+      my $json = encode_json_utf8($attr);
+      
+      $json =~ s/\{\[/\{ \[/g;
+      $json =~ s/\]\}/\] \}/g;
+      
+      $json
+    };
+    ## -----
+    
 		$conf->{renderer} = $rel_data->{self} ? jsfunc(
 			'function(value, metaData, record, rowIndex, colIndex, store) {' .
 				"var div_open = '$div_open';" .
@@ -1937,26 +1979,26 @@ sub get_multi_relationship_column_cnf {
 				#'var key_key = ' .
 				'var key_val = record && record.data ? record.data["' . $rSelfCol . '"] : null;' .
 				
-				'var attr = ' . RapidApp::JSON::MixedEncoder::encode_json($rel_data->{attrs}) . ';' .
+				#'var attr = ' . RapidApp::JSON::MixedEncoder::encode_json($rel_data->{attrs}) . ';' .
 				
 				( # TODO: needs to be generalized better
 					$conf->{open_url_multi} ?
 						'if(key_val && value && value > 0 && !Ext.ux.RapidApp.NO_DBIC_REL_LINKS) {' .
 							'var loadCfg = ' . RapidApp::JSON::MixedEncoder::encode_json($loadCfg) . ';' .
 							
-							'var join_name = "' . $conf->{open_url_multi_rs_join_name} . '";' .
+							'var join_name = "' . $join_name . '";' .
 							
 							'var cond = {};' .
 							'cond[join_name + ".' . $rel_data->{foreign} . '"] = key_val;' .
 							
 							#'var attr = {};' .
-							'if(join_name != "me"){ if(!attr.join) { attr.join = []; } attr.join.push(join_name); }' .
+							#'if(join_name != "me"){ if(!attr.join) { attr.join = []; } attr.join.push(join_name); }' .
 							
 							# Fix!!!
-							'if(join_name == "me" && Ext.isArray(attr.join) && attr.join.length > 0) { join_name = attr.join[0]; }' .
+							#'if(join_name == "me" && Ext.isArray(attr.join) && attr.join.length > 0) { join_name = attr.join[0]; }' .
 							
-							#Fix!!
-							'loadCfg.autoLoad.params.personality = join_name;' .
+							#Fix!! -- Note that 'personality' is for a specific legacy app
+							'loadCfg.autoLoad.params.personality = "' . $personality . '";' .
 							
 							#'loadCfg.autoLoad.params.base_params = Ext.encode({' .
 							#	'resultset_condition: Ext.encode(cond),' .
@@ -1965,7 +2007,8 @@ sub get_multi_relationship_column_cnf {
 							
 							'loadCfg.autoLoad.params.base_params_base64 = base64.encode(Ext.encode({' .
 								'resultset_condition: Ext.encode(cond),' .
-								'resultset_attr: Ext.encode(attr)' .
+								#'resultset_attr: Ext.encode(attr)' .
+                "resultset_attr: '" . $attr_json . "'" .
 							'}));' .
 							
 							'var href = "#loadcfg:" + Ext.urlEncode({data: Ext.encode(loadCfg)});' .
@@ -2036,8 +2079,7 @@ sub get_m2m_multi_relationship_column_cnf {
 	my $schema = $self->ResultSource->schema;
 	my $Source = $schema->source($rrinfo->{source});
 	
-	my $table = $self->ResultClass->table;
-	$table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+	my $table = RapidApp::DBIC::Component::TableSpec::_table_name_safe($self->ResultClass->table);
 	my $module_name = 'm2mcombo_' . $table . '_' . $colname;
 	my $Module = $self->get_or_create_rapidapp_module( $module_name,
 		class	=> 'RapidApp::Module::DbicCombo',
